<?php

namespace Drupal\document_ocr\Event;

use Drupal\Component\EventDispatcher\Event;
use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\file\FileInterface;

/**
 * Base class for TaskDestination events.
 */
abstract class TaskDestinationBase extends Event {

  /**
   * Initializes the event.
   *
   * @param \Drupal\file\FileInterface $file
   *   The file to process.
   * @param \Drupal\Core\Entity\ContentEntityInterface|null $entity
   *   The entity to fill with the processed data.
   */
  public function __construct(protected $file, protected ?ContentEntityInterface $entity) {
  }

  /**
   * Returns the entity to fill with the processed data.
   */
  public function setEntity(?ContentEntityInterface $entity): self {
    $this->entity = $entity;
    return $this;
  }

  /**
   * Returns the entity to fill with the processed data.
   */
  public function getEntity(): ?ContentEntityInterface {
    return $this->entity;
  }

  /**
   * Retrieves the processed file.
   */
  public function getFile(): FileInterface {
    return $this->file;
  }

}
